@@ -4,9 +4,11 @@
 import typing
 import os
 import subprocess
-import pwd
 import signal
 
+_bIsPOSIX = os.name == "posix"
+if _bIsPOSIX:
+	import pwd
 
 
 
@@ -109,84 +111,86 @@ def _demote(user_uid, user_gid):
 
 #
 
-#
-# Run a process as other user and wait until it terminates. No input or output is processed.
-# Of course for this to work you should be user <c>root</c>.
-#
-# @param	str accountName			The name of the user account under which to execute the process.
-# @param	str filePath			The path of the file to execute. This can be a bash script.
-# @param	str[] arguments			(optional) A list of arguments for the program to execute.
-# @param	AbstractLogger log		A logger that will receive log messages.
-# @return	bool					Returns <c>true</c> on success. <c>false</c> is returned if something went wrong.
-#									(In that case error log messages might have been generated, but no detailed error
-#									information is returned.)
-#
-def runProcessAsOtherUser(accountName:str, filePath:str, args:typing.Union[list,tuple], log) -> bool:
-	assert isinstance(accountName, str)
-	assert accountName
+if _bIsPOSIX:
 
-	assert isinstance(filePath, str)
-	assert filePath
-	assert os.path.isfile(filePath)
+	#
+	# Run a process as other user and wait until it terminates. No input or output is processed.
+	# Of course for this to work you should be user <c>root</c>.
+	#
+	# @param	str accountName			The name of the user account under which to execute the process.
+	# @param	str filePath			The path of the file to execute. This can be a bash script.
+	# @param	str[] arguments			(optional) A list of arguments for the program to execute.
+	# @param	AbstractLogger log		A logger that will receive log messages.
+	# @return	bool					Returns <c>true</c> on success. <c>false</c> is returned if something went wrong.
+	#									(In that case error log messages might have been generated, but no detailed error
+	#									information is returned.)
+	#
+	def runProcessAsOtherUser(accountName:str, filePath:str, args:typing.Union[list,tuple], log) -> bool:
+		assert isinstance(accountName, str)
+		assert accountName
 
-	if args is None:
-		args = []
-	else:
-		if isinstance(args, tuple):
-			args = list(args)
+		assert isinstance(filePath, str)
+		assert filePath
+		assert os.path.isfile(filePath)
+
+		if args is None:
+			args = []
 		else:
-			assert isinstance(args, list)
+			if isinstance(args, tuple):
+				args = list(args)
+			else:
+				assert isinstance(args, list)
 
-	# ----
+		# ----
 
-	if log:
-		log.notice("Running " + repr(filePath) + " as " + repr(accountName) + "...")
-
-	scriptDirPath = os.path.dirname(filePath)
-
-	pw_record = pwd.getpwnam(accountName)
-	accountName = pw_record.pw_name
-	user_home_dir = pw_record.pw_dir
-	uid = pw_record.pw_uid
-	gid = pw_record.pw_gid
-
-	currentUserID = os.getuid()
-	if currentUserID != 0:
-		if uid != currentUserID:
-			raise Exception("Must be root to run processes as other user!")
-
-	env = os.environ.copy()
-	env["HOME"     ]  = user_home_dir
-	env["LOGNAME"  ]  = accountName
-	env["PWD"      ]  = scriptDirPath
-	env["USER"     ]  = accountName
-
-	ret = True
-
-	try:
-		process = subprocess.Popen(
-			[ filePath ] + args,
-			preexec_fn = _demote(uid, gid),
-			cwd =  scriptDirPath,
-			env = env,
-		)
-		exitCode = process.wait()
-
-		if exitCode != 0:
-			if log:
-				log.error("Script " + repr(filePath) + " terminated with exit code: " + str(exitCode))
-			ret = False
-		else:
-			if log:
-				log.notice("Done running " + repr(filePath) + ".")
-
-	except Exception as ee:
 		if log:
-			log.error(ee)
-		ret = False
+			log.notice("Running " + repr(filePath) + " as " + repr(accountName) + "...")
 
-	return ret
-#
+		scriptDirPath = os.path.dirname(filePath)
+
+		pw_record = pwd.getpwnam(accountName)
+		accountName = pw_record.pw_name
+		user_home_dir = pw_record.pw_dir
+		uid = pw_record.pw_uid
+		gid = pw_record.pw_gid
+
+		currentUserID = os.getuid()
+		if currentUserID != 0:
+			if uid != currentUserID:
+				raise Exception("Must be root to run processes as other user!")
+
+		env = os.environ.copy()
+		env["HOME"     ]  = user_home_dir
+		env["LOGNAME"  ]  = accountName
+		env["PWD"      ]  = scriptDirPath
+		env["USER"     ]  = accountName
+
+		ret = True
+
+		try:
+			process = subprocess.Popen(
+				[ filePath ] + args,
+				preexec_fn = _demote(uid, gid),
+				cwd =  scriptDirPath,
+				env = env,
+			)
+			exitCode = process.wait()
+
+			if exitCode != 0:
+				if log:
+					log.error("Script " + repr(filePath) + " terminated with exit code: " + str(exitCode))
+				ret = False
+			else:
+				if log:
+					log.notice("Done running " + repr(filePath) + ".")
+
+		except Exception as ee:
+			if log:
+				log.error(ee)
+			ret = False
+
+		return ret
+	#
 
 
 
